@@ -9,8 +9,6 @@
 (*                                                                     *)
 (***********************************************************************)
 
-exception Error of string
-
+val static_libdir : string
 val libdir : string
-val put_from_lib : string -> (string -> unit) -> unit
-val copy_from_lib : string -> unit
+
